pub enum ParseDerivationPathError {
Child(ParseChildNumberError),
EmptyChild,
MissingMasterPrefix,
UnexpectedMasterPrefix,
}Expand description
Error parsing a derivation path.
Variants
Child(ParseChildNumberError)
Failed to parse a child number.
EmptyChild
The path contained an empty child number.
MissingMasterPrefix
The absolute path was missing the m master prefix.
UnexpectedMasterPrefix
The relative path unexpectedly contained the m master prefix.