#[non_exhaustive]pub struct IndexOutOfRangeError {
pub index: u32,
}Expand description
Out-of-range index when constructing a child number.
Indices are always in the range [0, 2^31 - 1]. Normal child numbers have the same range, while hardened child numbers lie in the range [2^31, 2^32 - 1].
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.index: u32The index that was out of range for a child number.