pub struct AbsoluteDerivationPath(/* private fields */);Expand description
An absolute BIP-0032 derivation path, starting at the master key.
Conversion to RelativeDerivationPath is available through
AbsoluteDerivationPath::as_relative or
AbsoluteDerivationPath::into_relative.
The leading m in BIP-0032 notation has historically been subtle in this crate:
See PR #2451 and PR #2677 for prior discussion on the “m/” notation.
Implementations
Sourceimpl AbsoluteDerivationPath
impl AbsoluteDerivationPath
Sourcepub fn as_relative(&self) -> &RelativeDerivationPath
pub fn as_relative(&self) -> &RelativeDerivationPath
Returns the relative path below the master key.
Sourcepub fn into_relative(self) -> RelativeDerivationPath
pub fn into_relative(self) -> RelativeDerivationPath
Converts this absolute path into the relative path below the master key.
Sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
Returns length of the relative derivation path below the master key.
Sourcepub fn contains_hardened_child(&self) -> bool
pub fn contains_hardened_child(&self) -> bool
Returns true if the relative path below the master key contains a hardened child number.
Sourcepub fn join<T: AsRef<[ChildNumber]>>(&self, path: T) -> Self
pub fn join<T: AsRef<[ChildNumber]>>(&self, path: T) -> Self
Joins self with path and returns the resulting new path.