pub struct ChildNumber(/* private fields */);Expand description
A child number for a derived key.
The high bit marks whether the index is hardened and the remaining bits store the actual index.
Implementations
Sourceimpl ChildNumber
impl ChildNumber
Sourcepub const ZERO_NORMAL: Self
pub const ZERO_NORMAL: Self
Normal child number with index 0.
Sourcepub const ONE_NORMAL: Self
pub const ONE_NORMAL: Self
Normal child number with index 1.
Sourcepub const ZERO_HARDENED: Self
pub const ZERO_HARDENED: Self
Hardened child number with index 0.
Sourcepub const ONE_HARDENED: Self
pub const ONE_HARDENED: Self
Hardened child number with index 1.
Sourcepub fn from_normal_idx(index: u32) -> Result<Self, IndexOutOfRangeError>
pub fn from_normal_idx(index: u32) -> Result<Self, IndexOutOfRangeError>
Constructs a new normal child number from an index.
Errors
Returns an error if the index is not within [0, 2^31 - 1].
Sourcepub fn from_hardened_idx(index: u32) -> Result<Self, IndexOutOfRangeError>
pub fn from_hardened_idx(index: u32) -> Result<Self, IndexOutOfRangeError>
Constructs a new hardened child number from an index.
Errors
Returns an error if the index is not within [0, 2^31 - 1].
Sourcepub fn from_raw(raw: u32) -> Self
pub fn from_raw(raw: u32) -> Self
Constructs a child number from its raw BIP-0032 representation.
The raw representation includes the hardened bit. Use Self::from_normal_idx or
Self::from_hardened_idx to construct a child number from an index.
Sourcepub fn to_raw(self) -> u32
pub fn to_raw(self) -> u32
Returns the raw BIP-0032 representation.
The raw representation includes the hardened bit. Use Self::index to get the child
index without the hardened bit.
Sourcepub fn is_hardened(&self) -> bool
pub fn is_hardened(&self) -> bool
Returns true if the child number is hardened.
Sourcepub fn increment(self) -> Result<Self, IndexOutOfRangeError>
pub fn increment(self) -> Result<Self, IndexOutOfRangeError>
Returns the child number that is a single increment from this one.
Errors
Returns an error if the index after incrementing will be outside the range [0, 2^31 - 1].