Xpriv

Struct Xpriv 

pub struct Xpriv {
    pub network: NetworkKind,
    pub depth: u8,
    pub parent_fingerprint: Fingerprint,
    pub child_number: ChildNumber,
    pub private_key: SecretKey,
    pub chain_code: ChainCode,
}
Extended private key

Fields

network: NetworkKind

The network this key is to be used on

depth: u8

How many derivations this key is from the master (which is 0)

parent_fingerprint: Fingerprint

Fingerprint of the parent key (0 for master)

child_number: ChildNumber

Child number of the key used to derive from parent (0 for master)

private_key: SecretKey

Private key

chain_code: ChainCode

Chain code

Implementations

Source

impl Xpriv

pub fn new_master( network: impl Into<NetworkKind>, seed: impl AsRef<Bip32Seed>, ) -> Self

Constructs a new master key from a Bip32Seed.

pub fn to_priv(self) -> PrivateKey

👎Deprecating in a future version:

use to_private_key() instead

Constructs a new ECDSA compressed private key matching internal secret key representation.

pub fn to_private_key(self) -> PrivateKey

Constructs a new ECDSA compressed private key matching internal secret key representation.

pub fn to_xpub(self) -> Xpub

Constructs a new extended public key from this extended private key.

pub fn to_keypair(self) -> Keypair

Constructs a new BIP-0340 keypair for Schnorr signatures and Taproot use matching the internal secret key representation.

pub fn derive_priv<P: AsRef<[ChildNumber]>>( &self, path: P, ) -> Result<Self, DerivationError>

👎Deprecating in a future version:

use derive_xpriv() instead

Derives an extended private key from a path.

The path argument can be both of type RelativeDerivationPath or Vec<ChildNumber>.

Errors

See derive_xpriv.

pub fn derive_xpriv<P: AsRef<[ChildNumber]>>( &self, path: P, ) -> Result<Self, DerivationError>

Derives an extended private key from a path.

The path argument can be both of type RelativeDerivationPath or Vec<ChildNumber>.

Errors

Returns an error if the derived key exceeds the maximum key depth.

pub fn decode(data: &[u8]) -> Result<Self, ParseError>

Decoding extended private key from binary data according to BIP-0032

Errors
pub fn encode(&self) -> [u8; 78]

Extended private key binary encoding according to BIP-0032

pub fn identifier(&self) -> XKeyIdentifier

Returns the HASH160 of the public key belonging to the xpriv

pub fn fingerprint(&self) -> Fingerprint

Returns the first four bytes of the identifier